==> datarouter-bytes-0.0.107-sources.jar: io/datarouter/bytes/binarydto/fieldcodec/BinaryDtoConvertingFieldCodec.java <==
/*
 * Copyright © 2009 HotPads (admin@hotpads.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.datarouter.bytes.binarydto.fieldcodec;

import java.util.function.Function;

import io.datarouter.bytes.Codec;
import io.datarouter.bytes.FunctionalCodec;
import io.datarouter.bytes.LengthAndValue;

public class BinaryDtoConvertingFieldCodec<R,T> extends BinaryDtoBaseFieldCodec<R>{

	private final Codec<R,T> converter;
	private final BinaryDtoBaseFieldCodec<T> codec;

	public BinaryDtoConvertingFieldCodec(
			Function<R,T> convertTo,
			Function<T,R> convertFrom,
			BinaryDtoBaseFieldCodec<T> codec){
		this.converter = new FunctionalCodec<>(convertTo, convertFrom);
		this.codec = codec;
	}

	public BinaryDtoConvertingFieldCodec(Codec<R,T> converter, BinaryDtoBaseFieldCodec<T> codec){
		this.converter = converter;
		this.codec = codec;
	}

	@Override
	public boolean isFixedLength(){
		return codec.isFixedLength();
	}

	@Override
	public int fixedLength(){
		return codec.fixedLength();
	}

	@Override
	public byte[] encode(R value){
		T convertedValue = converter.encode(value);
		return codec.encode(convertedValue);
	}

	@Override
	public R decode(byte[] bytes, int offset){
		T rawValue = codec.decode(bytes, offset);
		return converter.decode(rawValue);
	}

	@Override
	public LengthAndValue<R> decodeWithLength(byte[] bytes, int offset){
		LengthAndValue<T> rawLengthAndValue = codec.decodeWithLength(bytes, offset);
		R convertedValue = converter.decode(rawLengthAndValue.value);
		return new LengthAndValue<>(rawLengthAndValue.length, convertedValue);
	}

}

==> datarouter-bytes-0.0.113-sources.jar: io/datarouter/bytes/binarydto/fieldcodec/BinaryDtoConvertingFieldCodec.java <==
/*
 * Copyright © 2009 HotPads (admin@hotpads.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.datarouter.bytes.binarydto.fieldcodec;

import java.util.function.Function;

import io.datarouter.bytes.Codec;
import io.datarouter.bytes.LengthAndValue;

public class BinaryDtoConvertingFieldCodec<R,T> extends BinaryDtoBaseFieldCodec<R>{

	private final Codec<R,T> converter;
	private final BinaryDtoBaseFieldCodec<T> codec;

	public BinaryDtoConvertingFieldCodec(
			Function<R,T> convertTo,
			Function<T,R> convertFrom,
			BinaryDtoBaseFieldCodec<T> codec){
		this.converter = Codec.of(convertTo, convertFrom);
		this.codec = codec;
	}

	public BinaryDtoConvertingFieldCodec(Codec<R,T> converter, BinaryDtoBaseFieldCodec<T> codec){
		this.converter = converter;
		this.codec = codec;
	}

	@Override
	public boolean isFixedLength(){
		return codec.isFixedLength();
	}

	@Override
	public int fixedLength(){
		return codec.fixedLength();
	}

	@Override
	public byte[] encode(R value){
		T convertedValue = converter.encode(value);
		return codec.encode(convertedValue);
	}

	@Override
	public R decode(byte[] bytes, int offset){
		T rawValue = codec.decode(bytes, offset);
		return converter.decode(rawValue);
	}

	@Override
	public LengthAndValue<R> decodeWithLength(byte[] bytes, int offset){
		LengthAndValue<T> rawLengthAndValue = codec.decodeWithLength(bytes, offset);
		R convertedValue = converter.decode(rawLengthAndValue.value);
		return new LengthAndValue<>(rawLengthAndValue.length, convertedValue);
	}

}
